@@ -91,8 +91,11 @@ class DataFlowKernel:
         self._config = config
         self.run_dir = make_rundir(config.run_dir)
 
+        self._logging_unregister_callback: Optional[Callable[[], None]]
         if config.initialize_logging:
-            parsl.set_file_logger("{}/parsl.log".format(self.run_dir), level=logging.DEBUG)
+            self._logging_unregister_callback = parsl.set_file_logger("{}/parsl.log".format(self.run_dir), level=logging.DEBUG)
+        else:
+            self._logging_unregister_callback = None
 
         logger.info("Starting DataFlowKernel with config\n{}".format(config))
 
@@ -1139,7 +1142,7 @@ class DataFlowKernel:
                 executor.monitoring_messages = self.monitoring.resource_msgs
                 logger.debug("Starting monitoring receiver for executor %s "
                              "with remote monitoring radio config %s",
-                             executor, executor.remote_monitoring_radio)
+                             executor.label, executor.remote_monitoring_radio)
 
                 executor.monitoring_receiver = executor.remote_monitoring_radio.create_receiver(resource_msgs=executor.monitoring_messages,
                                                                                                 run_dir=executor.run_dir)
@@ -1185,12 +1188,9 @@ class DataFlowKernel:
 
     @wrap_with_logs
     def cleanup(self) -> None:
-        """DataFlowKernel cleanup.
-
-        This involves releasing all resources explicitly.
-
-        We call scale_in on each of the executors and call executor.shutdown.
+        """Clean-up by closing all of the components used by the DFK
         """
+
         logger.info("DFK cleanup initiated")
 
         # this check won't detect two DFK cleanups happening from
@@ -1258,9 +1258,16 @@ class DataFlowKernel:
         else:
             logger.debug("Cleaning up non-default DFK - not unregistering")
 
+        if self._logging_unregister_callback:
+            logger.info("Unregistering log handler")
+            self._logging_unregister_callback()
+            logger.info("Unregistered log handler")
+
+        # This message won't go to the default parsl.log, but other handlers
+        # should still see it.
         logger.info("DFK cleanup complete")
 
-    def checkpoint(self, tasks: Optional[Sequence[TaskRecord]] = None) -> str:
+    def checkpoint(self, tasks: Optional[Sequence[TaskRecord]] = None) -> None:
         """Checkpoint the dfk incrementally to a checkpoint file.
 
         When called, every task that has been completed yet not
@@ -1321,8 +1328,6 @@ class DataFlowKernel:
             else:
                 logger.info("Done checkpointing {} tasks".format(count))
 
-            return checkpoint_dir
-
     @staticmethod
     def _log_std_streams(task_record: TaskRecord) -> None:
         tid = task_record['id']
